@@ -193,6 +193,9 @@ void LibViewPanel::initConnect()
     connect(m_bottomToolbar, &LibBottomToolbar::sigOcr, this, &LibViewPanel::slotOcrPicture);
     connect(m_bottomToolbar, &LibBottomToolbar::sigLeaveBottom, this, &LibViewPanel::slotBottomMove);
 
+    connect(m_bottomToolbar, &LibBottomToolbar::sigResizeBottom, this, &LibViewPanel::slotBottomMove);
+
+
     connect(m_view, &LibImageGraphicsView::sigImageOutTitleBar, this, &LibViewPanel::slotsImageOutTitleBar);
 
 //    connect(m_view, &LibImageGraphicsView::sigImageOutTitleBar, m_topToolbar, &AbstractTopToolbar::setTitleBarTransparent);
@@ -200,7 +203,7 @@ void LibViewPanel::initConnect()
     connect(m_view, &LibImageGraphicsView::sigMouseMove, this, &LibViewPanel::slotBottomMove);
     connect(m_view, &LibImageGraphicsView::sigClicked, this, &LibViewPanel::slotChangeShowTopBottom);
 
-    connect(ImageEngine::instance(), &ImageEngine::sigOneImgReady, this, &LibViewPanel::slotOneImgReady);
+    connect(ImageEngine::instance(), &ImageEngine::sigOneImgReady, this, &LibViewPanel::slotOneImgReady, Qt::QueuedConnection);
 
     connect(m_view, &LibImageGraphicsView::UpdateNavImg, this, [ = ]() {
         m_nav->setImage(m_view->image());
@@ -600,7 +603,12 @@ void LibViewPanel::updateMenuContent(QString path)
         if (isReadable) {
             appendAction(IdDisplayInFileManager, QObject::tr("Display in file manager"),
                          ss("Display in file manager", "Alt+D"));
-            appendAction(IdImageInfo, QObject::tr("Image info"), ss("Image info", "Ctrl+I"));
+
+            if (isAlbum) {
+                appendAction(IdImageInfo, QObject::tr("Photo info"), ss("Image info", "Ctrl+I"));
+            } else {
+                appendAction(IdImageInfo, QObject::tr("Image info"), ss("Image info", "Ctrl+I"));
+            }
         }
     }
 }
@@ -862,6 +870,8 @@ bool LibViewPanel::startdragImage(const QStringList &paths, const QString &first
         } else if (image_list.count() > 0) {
             loadingPath = image_list.first();
         }
+        //stack设置正确位置
+        m_stack->setCurrentWidget(m_view);
         //展示当前图片
         loadImage(loadingPath, image_list);
 
@@ -874,6 +884,8 @@ bool LibViewPanel::startdragImage(const QStringList &paths, const QString &first
         loadThumbnails(path);
 
     } else if (LibCommonService::instance()->getImgViewerType() == imageViewerSpace::ImgViewerTypeAlbum) {
+        //stack设置正确位置
+        m_stack->setCurrentWidget(m_view);
         //展示当前图片
         loadImage(firstPath, paths);
         LibCommonService::instance()->m_listAllPath = paths;
@@ -1050,6 +1062,7 @@ void LibViewPanel::setCurrentWidget(const QString &path)
                 if ((m_bottomToolbar->getAllFileCount() <= 1 && ImgViewerType::ImgViewerTypeAlbum != LibCommonService::instance()->getImgViewerType()) ||
                         (m_bottomToolbar->getAllFileCount() == 0 && ImgViewerType::ImgViewerTypeAlbum == LibCommonService::instance()->getImgViewerType())) {
                     emit ImageEngine::instance()->sigPicCountIsNull();
+                    m_stack->setCurrentWidget(m_view);
                 }
             }
             if (m_nav) {
@@ -1191,6 +1204,8 @@ bool LibViewPanel::startChooseFileDialog()
         } else {
             loadingPath = image_list.first();
         }
+        //stack设置正确位置
+        m_stack->setCurrentWidget(m_view);
         //展示当前图片
         loadImage(loadingPath, image_list);
         LibCommonService::instance()->m_listAllPath = image_list;
@@ -1214,10 +1229,10 @@ void LibViewPanel::slotBottomMove()
     int nParentHeight = this->height();
 
     //如果没有显示则不执行动画
-    if (m_bottomToolbar && m_bottomToolbar->isVisible() && m_topToolbar) {
+    if (m_bottomToolbar && m_bottomToolbar->isVisible() && m_topToolbar && m_stack->currentWidget() != m_sliderPanel) {
         if (window()->isFullScreen() || m_ImageOutTitleBar) {
 
-            if ((m_stack->currentWidget() != m_sliderPanel && (((nParentHeight - (10 + m_bottomToolbar->height()) < pos.y() && nParentHeight > pos.y() && nParentHeight == m_bottomToolbar->y()) || (pos.y() < 50 && pos.y() >= 0)) && ((pos.x() > 2)) && (pos.x() < nParentWidth - 2)))) {
+            if ((/*m_stack->currentWidget() != m_sliderPanel &&*/ (((nParentHeight - (10 + m_bottomToolbar->height()) < pos.y() && nParentHeight > pos.y() && nParentHeight == m_bottomToolbar->y()) || (pos.y() < 50 && pos.y() >= 0)) && ((pos.x() > 2)) && (pos.x() < nParentWidth - 2)))) {
                 showAnimationTopBottom();
                 m_isShowTopBottom = true;
             } else if (!m_isShowTopBottom && !window()->isFullScreen()) {
@@ -1225,7 +1240,7 @@ void LibViewPanel::slotBottomMove()
             } else if ((nParentHeight - m_bottomToolbar->height() - 10 > pos.y() &&
                         nParentHeight - m_bottomToolbar->height() - 10 == m_bottomToolbar->y()) || pos.y() >= nParentHeight || pos.y() <= 0
                        || pos.x() < 2 || pos.x() > nParentWidth - 2 || (pos.y() > 50 && pos.y() <= nParentHeight - m_bottomToolbar->height() - 10)
-                       || m_stack->currentWidget() == m_sliderPanel) {
+                       /*|| m_stack->currentWidget() == m_sliderPanel*/) {
                 hideAnimationTopBottom();
                 m_isShowTopBottom = true;
             } else if (m_bottomToolbar->y() < nParentHeight - 100) {
@@ -1512,6 +1527,9 @@ void LibViewPanel::initShortcut()
             }
 //            toggleFullScreen();
             showNormal();
+            //需要关闭定时器
+            killTimer(m_hideCursorTid);
+            m_hideCursorTid = 0;
             m_view->viewport()->setCursor(Qt::ArrowCursor);
             //修复连续点击F5和esc的问题
             if (m_sliderPanel) {
@@ -1553,6 +1571,9 @@ void LibViewPanel::onMenuItemClicked(QAction *action)
             break;
         }
         case IdStartSlideShow: {
+            if (m_bottomToolbar) {
+                m_bottomToolbar->setVisible(false);
+            }
             ViewInfo vinfo;
             vinfo.fullScreen = window()->isFullScreen();
             vinfo.lastPanel = this;
@@ -1697,16 +1718,13 @@ void LibViewPanel::onMenuItemClicked(QAction *action)
             if (!m_info && !m_extensionPanel) {
                 initExtensionPanel();
             }
-            //重新刷新文件信息
-            m_info->updateInfo();
-            m_info->show();
-
             //判断是否有缓存,无缓存,则使用打开路径
             QString path = m_bottomToolbar->getCurrentItemInfo().path;
             if (path.isEmpty()) {
                 path = m_currentPath;
             }
-            m_info->setImagePath(path);
+            m_info->setImagePath(path); //执行强制重刷
+            m_info->show();
             m_extensionPanel->setContent(m_info);
             //清除焦点
             m_extensionPanel->setFocus(Qt::NoFocusReason);
@@ -1875,7 +1893,7 @@ void LibViewPanel::slotRotateImage(int angle)
         });
     }
     m_tSaveImage->setSingleShot(true);
-    m_tSaveImage->start(2000);
+    m_tSaveImage->start(1000);
 }
 
 void LibViewPanel::slotResetTransform(bool bRet)
@@ -2021,3 +2039,13 @@ void LibViewPanel::leaveEvent(QEvent *event)
     }
     return QFrame::leaveEvent(event);
 }
+
+void LibViewPanel::hideEvent(QHideEvent *e)
+{
+    if (m_info && m_extensionPanel) {
+        m_info->setVisible(false);
+        m_extensionPanel->setVisible(false);
+    }
+
+    QFrame::hideEvent(e);
+}
